package application;

import java.io.IOException;

import javafx.beans.property.IntegerProperty;
import javafx.beans.property.SimpleIntegerProperty;
import javafx.beans.value.ChangeListener;
import javafx.beans.value.ObservableValue;
import javafx.event.ActionEvent;
import javafx.event.EventHandler;
import javafx.fxml.FXML;
import javafx.fxml.FXMLLoader;
import javafx.scene.Scene;
import javafx.scene.control.Button;
import javafx.scene.control.Label;
import javafx.scene.layout.VBox;
import javafx.stage.Stage;
import javafx.stage.WindowEvent;

public class LaunchAnotherStageMainVBox extends VBox {

    @FXML
    private Label labelMe;

    @FXML
    private Label labelTotal;

    @FXML
    private Button buttonLaunch;
    
    private Stage stage = null; // stage for parent of myself
    private LaunchAnotherStage anotherStage = null; // stage for myChild if buttonLaunch is pressed

	public static IntegerProperty total = new SimpleIntegerProperty(0); // initial value is zero
	
	public IntegerProperty totalProperty() {
		return total;
	}
	
	public int getTotal() {
		return total.get();
	}
	
	public void setTotal(int i) {
		total.set(i);
	}
	
	private int me = 0;
	
    @FXML
    void initialize() {
    	
    	total.addListener(new ChangeListener<Number>() {

			@Override
			public void changed(ObservableValue<? extends Number> ov, Number oldValue, Number newValue) {
				labelTotal.setText(""+newValue.intValue()); // set labelTotal to be the current value of total
			}
    		
    	});
    	
		total.set(total.get()+1); // increase total by one
		me = total.get(); // me is the same as total
		
		labelTotal.setText(""+total.get());
		labelMe.setText(""+me);
		
    	stage.showingProperty().addListener(new ChangeListener<Boolean>() {

			@Override
			public void changed(ObservableValue<? extends Boolean> ov, Boolean oldValue, Boolean newValue) {
				if (oldValue && !newValue) {
					// stage is closing
					if (anotherStage != null) {
						// close anotherStage
						anotherStage.fireEvent(new WindowEvent(stage, WindowEvent.WINDOW_CLOSE_REQUEST));
					}
					// revise total properly
					total.set(me-1);
				}
			}
    		
    	});
    	
    	buttonLaunch.setOnAction(new EventHandler<ActionEvent>() {

			@Override
			public void handle(ActionEvent event) {
				buttonLaunch.setDisable(true);
				anotherStage = new LaunchAnotherStage();
				
				// move anotherStage to the right and to the down from the original center position
				anotherStage.setX(anotherStage.getX()+120*(total.get()-1));
				anotherStage.setY(anotherStage.getY()+120*(total.get()-1));
				anotherStage.showingProperty().addListener(new ChangeListener<Boolean>() {

					@Override
					public void changed(ObservableValue<? extends Boolean> ov, Boolean oldValue, Boolean newValue) {
						if (oldValue && !newValue) {
							// anotherStage is closing
							anotherStage = null;
							buttonLaunch.setDisable(false);
						}
					}
					
				});
			}
    		
    	});
    	
    }
    
    public LaunchAnotherStageMainVBox(Stage stage) {
    	
    	this.stage = stage;
    	
    	FXMLLoader fxmlLoader = new FXMLLoader(getClass().getResource("LaunchAnotherStageMainVBox.fxml"));
    	fxmlLoader.setRoot(this);
    	fxmlLoader.setController(this);
           	
    	try {
    		fxmlLoader.load();
    	} catch (IOException exception) {
    		throw new RuntimeException(exception);
    	}
    	
    }
    
    public class LaunchAnotherStage extends Stage {
    	
    	public LaunchAnotherStage() { // same as the start(stage) of Main class
    		try {
    			LaunchAnotherStageMainVBox root = new LaunchAnotherStageMainVBox(this);
    			Scene scene = new Scene(root, 290, 100);
    			this.setScene(scene);
    			this.setTitle("Launch Another Stage");
    			this.show();
    		} catch(Exception e) {
    			e.printStackTrace();
    		}
    		
    	}
    }
    
}
